veyron/lib/flags: Switch default veyron.tcp.prototcol to "wsh".

Switch default default proxyd protocol to "wsh".

Allow "wsh", "wsh4", and "wsh6" as valid protocols.

Change-Id: I684cfe497776372a88c04422af70d8c63ef7b2bc
diff --git a/lib/flags/listen.go b/lib/flags/listen.go
index 1812fe4..344bae4 100644
--- a/lib/flags/listen.go
+++ b/lib/flags/listen.go
@@ -6,8 +6,8 @@
 	"strconv"
 )
 
 // TCPProtocolFlag implements flag.Value to provide validation of the
 // command line values passed to it: tcp, tcp4 or tcp6, ws, ws4 and ws6
 // being the only allowed values.
 type TCPProtocolFlag struct{ Protocol string }
 
@@ -19,7 +19,7 @@
 // Implements flag.Value.Set
 func (t *TCPProtocolFlag) Set(s string) error {
 	switch s {
-	case "tcp", "tcp4", "tcp6", "ws", "ws4", "ws6":
+	case "tcp", "tcp4", "tcp6", "ws", "ws4", "ws6", "wsh", "wsh4", "wsh6":
 		t.Protocol = s
 		return nil
 	default:
@@ -6,8 +6,8 @@
 )
 
-// TCPProtocolFlag implements flag.Value to provide validation of the
-// command line values passed to it: tcp, tcp4 or tcp6, ws, ws4 and ws6
+// TCPProtocolFlag implements flag.Value to provide validation of the command
+// line values passed to it: tcp, tcp4, tcp6, ws, ws4, ws6, wsh, wsh4, and wsh6
 // being the only allowed values.
 type TCPProtocolFlag struct{ Protocol string }